Description Usage Arguments Value Examples
View source: R/format_atlcan.R
Format Atlantic Canada Shorebirds banding data for BandedBirds.org
1 | format_atlcan(x, project = y)
|
x |
A dataframe of Atlantic Canada Shorebirds banding data |
y |
The ProjectID number assigned by BandedBirds.org |
A dataframe of banding data formatted for submission to BandedBirds.org
1 | format_atlcan(banding_data, project = 99)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.