format_bandedbirds: Tidy BandedBirds.org data

Description Usage Arguments Value Examples

View source: R/format_bandedbirds.R

Description

Tidy BandedBirds.org data

Usage

1
format_bandedbirds(x, new_df = y, sp = NA, cert = TRUE)

Arguments

x

A dataframe formatted as submitted to BandedBirds.org.

new_df

A name for the new dataframe that will be created.

sp

Which species do you want to create encounter histories for? Use the four-letter AOU codes.

cert

Was resight certainty consistently recorded? Defaults to TRUE.

Value

Dataframe with columns for ResightDate and FlagID (flag colour and code).

Examples

1
format_bandedbirds(bandedbirds, new_df = resight_data, sp = "REKN", cert = TRUE)

ajmacdonald3/bb2enchist documentation built on Nov. 5, 2019, 4:47 p.m.