Description Usage Arguments Value Examples
View source: R/format_bandedbirds.R
Tidy BandedBirds.org data
1 | format_bandedbirds(x, new_df = y, sp = NA, cert = TRUE)
|
x |
A dataframe formatted as submitted to BandedBirds.org. |
new_df |
A name for the new dataframe that will be created. |
sp |
Which species do you want to create encounter histories for? Use the four-letter AOU codes. |
cert |
Was resight certainty consistently recorded? Defaults to TRUE. |
Dataframe with columns for ResightDate and FlagID (flag colour and code).
1 | format_bandedbirds(bandedbirds, new_df = resight_data, sp = "REKN", cert = TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.